@@ -8,10 +8,11 @@ from .setup_gui import CredentialsGUI, EmailGUI, SQLServerGUI
 
 import os
 import pkg_resources
+import sys
 
 __package_name__ = 'KGlobal'
 __author__ = 'Kevin Russell'
-__version__ = "1.4.5"
+__version__ = "1.4.6"
 __description__ = '''File, encryption, SQL, XML, and etc...'''
 __url__ = 'https://github.com/KLRussell/Python_KGlobal_Package'
 
@@ -28,9 +29,11 @@ __all__ = [
 
 
 def default_key_dir():
-    if isinstance(__path__, list):
-        path = __path__[0]
+    if getattr(sys, 'frozen', False):
+        path = sys._MEIPASS
+    elif isinstance(__path__, list):
+        path = os.path.join(__path__[0], "Keys")
     else:
-        path = __path__
+        path = os.path.join(__path__, "Keys")
 
-    return os.path.join(path, "Keys")
+    return path
